package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut


__DATA__
M?T5,1@("`0`````````````#`!8````!````````)@@`````````0```````
M`,'X``````!``#@`"0!``!L`&@````8````%`````````$``````````0```
M``````!``````````?@````````!^``````````(`````P````0````````"
M.`````````(X`````````C@`````````#P`````````/``````````$````!
M````!0```````````````````````````````````````*_D````````K^0`
M```````0``````$````&````````NT@```````#+2````````,M(````````
M!7`````````5H````````!```````@````8```````"[8````````,M@````
M````RV`````````"0`````````)```````````@````$````!`````````)(
M`````````D@````````"2`````````!$`````````$0`````````!&1TY5``
M```$````````J;````````"IL````````*FP`````````-0`````````U```
M```````$9'3E40````8`````````````````````````````````````````
M`````````````````````!!D=.52````!````````+M(````````RT@`````
M``#+2`````````2X````````!+@``````````2]L:6(O;&0V-"YS;RXQ````
M```$````$`````%'3E4```````````,````"``````````0````4`````T=.
M50#D`7_F$W;I@J4%,TATOVLQ9HR5%@`````````1````2@````0````(A`1`
M!0`0$""``(:````"*`D$(`D``"F""`($ND48H(@`````````2@```$X```!2
M````4P```%D```!:````6P```%T```!>`````````&````!A````8@```&,`
M`````````!_?Q6X.[]/J+4?>SGR:?VNVF\4N#N3_(`[QC;A\U&35'%AQV0'&
M1^+`XTNL?)+CNBP_Y<)@;*'Z;XL!L]9#"6MFS*]G[-5%0M-P!XF>XA0-GN/-
MVNW;8C,+ESH-FYRI?PH"I^%)^^"C````````````````````````````````
M```````````#```+````````&X@``````````````KD2````````````````
M`````````````S0B`````````````````````````````@L2````````````
M`````````````````!$@`````````````````````````````W(1````````
M`````````````````````]42`````````````````````````````O\1````
M`````````````````````````U$2`````````````````````````````242
M`````````````````````````````,@2````````````````````````````
M`9<2`````````````````````````````L`2````````````````````````
M`````)@2`````````````````````````````2`2````````````````````
M`````````GX2`````````````````````````````P82````````````````
M`````````````141`````````````````````````````IP2````````````
M`````````````````7L2`````````````````````````````/<1````````
M`````````````````````4D2`````````````````````````````-82````
M`````````````````````````<42`````````````````````````````PT2
M`````````````````````````````DT2````````````````````````````
M`B$2`````````````````````````````;(2````````````````````````
M`````JL2`````````````````````````````H\2````````````````````
M`````````;X2`````````````````````````````5<2````````````````
M`````````````Q82`````````````````````````````"T@````````````
M`````````````````E\2`````````````````````````````=`1````````
M`````````````````````R,2`````````````````````````````'@2````
M`````````````````````````V`2`````````````````````````````@02
M`````````````````````````````*<2````````````````````````````
M`A`2`````````````````````````````T,2````````````````````````
M`````+,2`````````````````````````````7`2````````````````````
M`````````I82`````````````````````````````FP2````````````````
M`````````````382`````````````````````````````J02````````````
M`````````````````&H2`````````````````````````````2H2````````
M`````````````````````M02`````````````````````````````:<2````
M`````````````````````````L82`````````````````````````````002
M`````````````````````````````UD2````````````````````````````
M`K(2`````````````````````````````W,A````````````````````````
M`````8D2`````````````````````````````(<2````````````````````
M`````````#P@`````````````````````````````.@2````````````````
M`````````````6<2`````````````````````````````RH2````````````
M`````````````````F02`````````````````````````````%`@````````
M`````````````````````W01`````````````````````````````O42````
M`````````````````````````BD2`````````````````````````````N(2
M`````````````````````````````G42````````````````````````````
M`CT2`````````````````````````````NT2````````````````````````
M`````]X2```-````````9J``````````Q````ZP2```.````````:`@`````
M````````!`,2```-````````5H@````````+E@```VT2```-````````(R@`
M```````"X````[(2```-````````3D``````````!@``!'$2```-````````
M3D@````````"7@``!&L2```+````````&X@`````````````!)X2```-````
M````8B`````````$>@```Y$0```8````````T+@``````````````^H2```-
M````````4*@`````````4@``!!T1```/````````:#@`````````!````YT0
M```8````````X.@`````````````!&D2```-````````3%``````````1@``
M!'X2```-````````52@````````!7```!)`2```-````````5#@`````````
ML```!!`0```7````````T````````````````_<2```-````````40``````
M```!>````XH0```7````````T+@`````````````!%(1```7````````T+``
M````````"````Z(2```-````````:````````````@``!$(2```-````````
M9Y@`````````9```!!82```-````````)@@`````````````!!(@```7````
M````T````````````````\,2```-````````5.@`````````.@``!"P2```-
M````````31`````````!+@``!%P2```-````````4G@````````!O@!L:6)P
M97)L+G-O+C4N,C0`7TE435]D97)E9VES=&5R5$U#;&]N951A8FQE`%]?9VUO
M;E]S=&%R=%]?`%]*=E]296=I<W1E<D-L87-S97,`7TE435]R96=I<W1E<E1-
M0VQO;F5486)L90!097)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S`%!E<FQ?
M871F;W)K7VQO8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`4&5R;%]C
M<F]A:U]N;V-O;G1E>'0`4&5R;%]A=E]S:&EF=`!097)L7W-V7S)P=E]F;&%G
M<P!097)L7W-V7W-E='!V;@!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G
M<P!03%]T:')?:V5Y`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R
M:U]U;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R
M=6X`4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O
M=%]$>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E
M<FQ?86QL;V,`4$Q?;65M;W)Y7W=R87``;&EB9&PN<V\N,@!L:6)M+G-O+C8`
M;&EB<'1H<F5A9"YS;RXP`&]P96XV-`!R96%D`%]?97)R;F]?;&]C871I;VX`
M;'-E96LV-`!P=&AR96%D7V=E='-P96-I9FEC`&-L;W-E`&QI8F,N<V\N-@!?
M7W)E9VES=&5R7V%T9F]R:P!E>&ET`'-T<FYC;7``7U]S=')D=7``8VQO<V5D
M:7(`7U]S=&%C:U]C:&M?9F%I;`!U;FQI;FL`;6MD:7(`<F5A;&QO8P!M96UC
M:'(`9V5T<&ED`'-T<G1O:P!S=')S='(`<FUD:7(`7U]F<')I;G1F7V-H:P!?
M7W-T<FYC<'E?8VAK`%]?;'AS=&%T-C0`;W!E;F1I<@!?7WAS=&%T-C0`<W1D
M97)R`&=E='5I9`!R96%D;&EN:P!?7VUE;6-P>5]C:&L`<W1R8VAR`')E861D
M:7(V-`!?7V-X85]F:6YA;&EZ90!?7W-P<FEN=&9?8VAK`&UE;6UO=F4`86-C
M97-S`%]?;&EB8U]S=&%R=%]M86EN`%]?96YV:7)O;@!L:6)C<GEP="YS;RXQ
M`%]E9&%T80!?7V)S<U]S=&%R=`!?96YD`%]?;&EB8U]C<W5?9FEN:0!P87)?
M8W5R<F5N=%]E>&5C`&=E=%]U<V5R;F%M95]F<F]M7V=E='!W=6ED`'!A<E]C
M;&5A;G5P`'!A<E]B87-E;F%M90!P87)?9&ER;F%M90!P87)?;6MT;7!D:7(`
M7U]D871A7W-T87)T`%])3U]S=&1I;E]U<V5D`'!A<E]C=7)R96YT7V5X96-?
M<')O8P!?7VQI8F-?8W-U7VEN:70`;7E?<&%R7W!L`'!A<E]I;FET7V5N=@!X
M<U]I;FET`'!A<E]F:6YD<')O9P!P87)?<V5T=7!?;&EB<&%T:`!P87)?96YV
M7V-L96%N`%A37TEN=&5R;F%L<U]005)?0D]/5`!'3$E"0U\R+C(`1TQ)0D-?
M,BXS+C0`1TQ)0D-?,BXS+C(`1TQ)0D-?,BXT`````````@`"``,````"``(`
M`@`"``(```````(```````0``@````(```````````````(`!0`#`````@`"
M``(````&`````@````(````"``,````#``0```````(``@````(```````8`
M```$`````@`"``(```````````````(``@````(``@`#``(``@`#``(``0`!
M``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$``0`!``$`
M`0`!``$``0```?0````0````(`UI:1(````#```$M````````0`$```"0P``
M`!``````"6D9=`````8```2^````$`EI&7(````%```$R@```!`-:6D4````
M!```!-8````0#6EI$@````(```2T`````````````,M(``````````P`````
M```G*````````,M0``````````P````````FT````````,_```````````P`
M``````#0"````````,_8``````````P````````C*````````-`(````````
M``P```````#0"````````-`0``````````P```````!J\@```````-`8````
M``````P```````!JV@```````-`@``````````P```````!JX@```````-`H
M``````````P```````!K"````````-`P``````````P```````!J\```````
M`-`X``````````P```````!K`@```````-!(``````````P```````!K^```
M`````-!0``````````P```````!IZ````````-!@``````````P```````!J
MG@```````-!H``````````P```````!JH@```````-!P``````````P`````
M``!K_@```````-!X``````````P```````!I[@```````-"```````````P`
M``````!L!@```````-"0``````````P```````!L"@```````-"8````````
M``P```````!L$````````-"P``````````P```````!LL@```````,^(````
M`P````H``````````````````,^0````!0````H``````````````````,^8
M````"`````H``````````````````,^@````#`````H`````````````````
M`,^H````$@````H``````````````````,^P````%0````H`````````````
M`````,^X````(@````H``````````````````,_(````)`````H`````````
M`````````,_0````,`````H``````````````````,_@````/`````H`````
M`````````````,_H````/0````H``````````````````,_P````0@````H`
M`````````````````,_X````0P````H``````````````````,VX`````@``
M``L``````````````````,W``````P````L``````````````````,W(````
M!`````L``````````````````,W0````!P````L``````````````````,W8
M````"0````L``````````````````,W@````"@````L`````````````````
M`,WH````"P````L``````````````````,WP````#0````L`````````````
M`````,WX````#@````L``````````````````,X`````#P````L`````````
M`````````,X(````$`````L``````````````````,X0````$0````L`````
M`````````````,X8````$P````L``````````````````,X@````%`````L`
M`````````````````,XH````%@````L``````````````````,XP````%P``
M``L``````````````````,XX````&`````L``````````````````,Y`````
M&0````L``````````````````,Y(````&@````L``````````````````,Y0
M````&P````L``````````````````,Y8````'`````L`````````````````
M`,Y@````'0````L``````````````````,YH````'@````L`````````````
M`````,YP````'P````L``````````````````,YX````(`````L`````````
M`````````,Z`````(0````L``````````````````,Z(````(P````L`````
M`````````````,Z0````)0````L``````````````````,Z8````)@````L`
M`````````````````,Z@````)P````L``````````````````,ZH````*```
M``L``````````````````,ZP````*0````L``````````````````,ZX````
M*@````L``````````````````,[`````*P````L``````````````````,[(
M````+`````L``````````````````,[0````+0````L`````````````````
M`,[8````+@````L``````````````````,[@````+P````L`````````````
M`````,[H````,0````L``````````````````,[P````,@````L`````````
M`````````,[X````,P````L``````````````````,\`````-`````L`````
M`````````````,\(````-0````L``````````````````,\0````-@````L`
M`````````````````,\8````-P````L``````````````````,\@````.```
M``L``````````````````,\H````.0````L``````````````````,\P````
M.P````L``````````````````,\X````/@````L``````````````````,]`
M````/P````L``````````````````,](````0`````L`````````````````
M`,]0````00````L``````````````````,]8````1`````L`````````````
M`````,]@````10````L``````````````````,]H````1@````L`````````
M`````````,]P````1P````L``````````````````,]X````2`````L`````
M`````````````,^`````20````L``````````.MO\#``)+D$`!^G^_]@XQ#P
M```DP,```%D"P!```%H+XQ`0```$N0(`$:>$``,-X>-`\1``!.MO\-``!`?T
M!P?C$/`X`"3`$```6.G2!_`P$`CC$!`0``0'\0<`!P`'`,`0``!8Z.,0$```
M!`?Q#1#C$!`,`!3`]/___^4`````P!```%C<XQ`0```$!_$-$.,0$`P`%,#T
M____U0```!C`$```6-#C$!````0'\0T0XQ`0#``4P/3____%````,,`0``!8
MQ.,0$```!`?Q#1#C$!`,`!3`]/___[4```!(P!```%BXXQ`0```$!_$-$.,0
M$`P`%,#T____I0```&#`$```6*SC$!````0'\0T0XQ`0#``4P/3___^5````
M>,`0``!8H.,0$```!`?Q#1#C$!`,`!3`]/___X4```"0P!```%B4XQ`0```$
M!_$-$.,0$`P`%,#T____=0```*C`$```6(CC$!````0'\0T0XQ`0#``4P/3_
M__]E````P,`0``!8?.,0$```!`?Q#1#C$!`,`!3`]/___U4```#8P!```%AP
MXQ`0```$!_$-$.,0$`P`%,#T____10```/#`$```6&3C$!````0'\0T0XQ`0
M#``4P/3___\U```!",`0``!86.,0$```!`?Q#1#C$!`,`!3`]/___R4```$@
MP!```%A,XQ`0```$!_$-$.,0$`P`%,#T____%0```3C`$```6$#C$!````0'
M\0T0XQ`0#``4P/3___\%```!4,`0``!8-.,0$```!`?Q#1#C$!`,`!3`]/__
M_O4```%HP!```%@HXQ`0```$!_$-$.,0$`P`%,#T___^Y0```8#`$```6!SC
M$!````0'\0T0XQ`0#``4P/3___[5```!F,`0``!8$.,0$```!`?Q#1#C$!`,
M`!3`]/___L4```&PP!```%@$XQ`0```$!_$-$.,0$`P`%,#T___^M0```<C`
M$```5_CC$!````0'\0T0XQ`0#``4P/3___ZE```!X,`0``!7[.,0$```!`?Q
M#1#C$!`,`!3`]/___I4```'XP!```%?@XQ`0```$!_$-$.,0$`P`%,#T___^
MA0```A#`$```5]3C$!````0'\0T0XQ`0#``4P/3___YU```"*,`0``!7R.,0
M$```!`?Q#1#C$!`,`!3`]/___F4```)`P!```%>\XQ`0```$!_$-$.,0$`P`
M%,#T___^50```EC`$```5[#C$!````0'\0T0XQ`0#``4P/3___Y%```"<,`0
M``!7I.,0$```!`?Q#1#C$!`,`!3`]/___C4```*(P!```%>8XQ`0```$!_$-
M$.,0$`P`%,#T___^)0```J#`$```5XSC$!````0'\0T0XQ`0#``4P/3___X5
M```"N,`0``!7@.,0$```!`?Q#1#C$!`,`!3`]/___@4```+0P!```%=TXQ`0
M```$!_$-$.,0$`P`%,#T___]]0```NC`$```5VCC$!````0'\0T0XQ`0#``4
MP/3___WE```#`,`0``!77.,0$```!`?Q#1#C$!`,`!3`]/___=4```,8P!``
M`%=0XQ`0```$!_$-$.,0$`P`%,#T___]Q0```S#`$```5T3C$!````0'\0T0
MXQ`0#``4P/3___VU```#2,`0``!7..,0$```!`?Q#1#C$!`,`!3`]/___:4`
M``-@P!```%<LXQ`0```$!_$-$.,0$`P`%,#T___]E0```WC`$```5R#C$!``
M``0'\0T0XQ`0#``4P/3___V%```#D,`0``!7%.,0$```!`?Q#1#C$!`,`!3`
M]/___74```.HP!```%<(XQ`0```$!_$-$.,0$`P`%,#T___]90```\#`$```
M5OSC$!````0'\0T0XQ`0#``4P/3___U5```#V,`0``!6\.,0$```!`?Q#1#C
M$!`,`!3`]/___44```/PP!```%;DXQ`0```$!_$-$.,0$`P`%,#T___]-0``
M!`C`$```5MCC$!````0'\0T0XQ`0#``4P/3___TE```$(,`0``!6S.,0$```
M!`?Q#1#C$!`,`!3`]/___14```0XP!```%;`XQ`0```$!_$-$.,0$`P`%,#T
M___]!0``!%#`$```5K3C$!````0'\0T0XQ`0#``4P/3___SU```$:,`0``!6
MJ.,0$```!`?Q#1#C$!`,`!3`]/___.4```2`P!```%:<XQ`0```$!_$-$.,0
M$`P`%,#T___\U0``!)C`$```5I#C$!````0'\0T0XQ`0#``4P/3___S%```$
ML,`0``!6A.,0$```!`?Q#1#C$!`,`!3`]/___+4```3(P!```%9XXQ`0```$
M!_$-$.,0$`P`%,#T___\I0``!.#`$```5FSC$!````0'\0T0XQ`0#``4P/3_
M__R5```$^,`0``!68.,0$```!`?Q#1#C$!`,`!3`]/___(4```40P!```%94
MXQ`0```$!_$-$.,0$`P`%,#T___\=0``!2C`$```5DCC$!````0'\0T0XQ`0
M#``4P/3___QE```%0,`0``!6/.,0$```!`?Q#1#C$!`,`!3`]/___%4```58
MZV_P,``DP-```",EI_O_.+)/`!#K$0`@``VR3P`1XS#PJ``DXT#PH``D4"#P
MM$%`\*!!,/"H02#PM-('\,`0*,#E___^`,`P``!6,<`0``!6-N-`,```!.,@
M$```!+D$`#3`Y0``(>_`$```5A#C$!````25`!``IX0`U\"P``!6`N,0L```
M!.,@$```%L#E____:<`0``!5]I8")/+C$!````3C(!```!;`Y?___UM8$/"T
MIQH`!98!)/*Y%``1XQ#0```AIR0`Z.LA``,`#<#E___]..,P\*@`!,"@``!>
M8L!0``!64\"P``!>8.,@H```)..@,```!,`````D1,`0```D0UA`\+3CH"``
M`"3C4%````2GJ``$4*"P`.,`(`@`).-0(!``).,0(!@`)*=.``&GQ``>&`1!
M,#`(I[@`!:=9\`"G"O__N10`&^L1``,`#>.@,```!*>Z``&G.P`(01$@`..E
M'_@`)*<&_^\8%*<:``2Y%``1ZQ$``P`-ISGP`,"P``!>&J=*``.Y!`!201$@
M`*<I``#C(3_X`"2Y%`!$XR"P```$IVD``,`P```3X<#E___^)A(B&**GA`!4
MXR"P```$P.7___Q,09#PO+D$`#G`(```(I[`Y0``#Y*Y`@`BIX0`2>,@L```
M!,#E___[^,#E___]U;)/`!#K$0`@``VR3P`1N10`*M4'\,`0**=T`%[C0/$X
M``3K;_#X``0'],#E___\3<`P``!=QKD"`"+C(#```"2GA`!-P.7___O`P+``
M`%4=XQ"P```$XR`0```6P.7___Z$D@`H]:?T_Q#C(+````3`Y?___CH8HJ?T
M_Z?`@```79SC((````2Y`@`BIX0`$\#E```@=J?T_ZS`$```507`(```(M[C
M,!````3`Y?___2RY!``YP"```"((P.4```\DXR"````DN0(`(J>$_Y&G]/_@
MP.7___N8IRD``<#E___\DT%`\`CC,/````2G"?_PN8``\*?[_U#7!_``\`#K
M[_"@`"1!</"@P&```"#IP%```""RP"```%3/XR`@```$P.7___RA```'!\!0
M```@^,`0``!5,<`@``!5+D$0$`>Y"0`2XQ!0```A!\[`$```5(_C$!````2Y
M`@`1!XX'\0<'P!```%48P#```%45N0D`,>LS``,`"NL3`#\`#+D(`#'K,P`!
M``H'CL`0``!4H.,0$```!+D"`!$'CL`@``!4^P?Q!P<'!P<'Z[_P6``DP-``
M`""YI_O_8,"P``!4[)4`L`"G=``8P!```%1-U0?0`!``IX0`"\`0``!4A>,@
M$```!,#E___Z?\#E____H)(!L`#C0/$0``3KO_#X``0'].O?\&@`),#0```@
MD:?[_V#`(```4A#5!]``(`"G=``(Z]_Q"``$P/3___^=P!```%1*XQ`0```$
MN0(`$:>$__(-X:?T_^\'!^MO\#``),#0```@<:?[_-"R3P`0ZQ$`(``-LD\`
M$4%`\*A!L"`XN00`-*=9``C2!_,H$"CC$+````3K`0`@``SC$-`@`(#C`#``
M`"3C$#`(`"1!L+`(ISL`$*=7_^U!4/*HXQ!`:``$XQ!`0`""XQ!`$`""XQ!`
M``""ZS$``0`-ZQ$`'P`,N8$`$^,0T"``@.,00(``)*=+``BY(`!4IW3_XN,0
M(!``!.,0\*``).-`(```!.,`T!@`!.,P\*``!.N4``4`#>,`\*@`".,P(!@`
M@NL4`!L`#..P(`@`!..@(`@`!+F!`!GC`"`@``CC,"`(`(#KJ@`"``SKNP`>
M``VY&@`!N8$`NN,P(!@`@N.PT"``@+D(`##C$/"@``2Y@@`;N00`D^,`T!@`
M!..0T"``@+F``!3C`/"P``CC$/"@`(+K>0`;``SC`"`8``CKJ0`%``VY@0"G
MZV0``@`,N0@``>N$`!X`#;D:``JY@0"&IVG__^.`T"``@+F"`&FY!`!PN00`
M$^,PT!@`!.-PT"``@+F``&NY@``8XS#PN``(N8$`%NM7``4`#>,P\*``".NG
M`!L`#.MI`!X`#>N9``(`#+F!`*6Y@0!IN0@`,;D:`#JY!`"FIVG__^.@T"``
M@+F"`&?C$-`8``2Y!`"3XY#0(`"`N8``:.,0\,``"+F```JY@0`&N0@`&^M9
M``4`#>MI`!L`#+F!`&6Y"``0Z[<`'@`-ZW<``@`,N1H`%KF!`+>G>?__X[#0
M(`"`N8(`>>-@T!@`!+D$``'C`-`@`("Y@`!ZXV#PR``(N8``.[D(`&BY@0`W
MZU``!0`-ZW``&P`,N8$`=;D(`#;KB0`>``WKF0`"``RY&@`WN8$`B:=Y___C
M@-`@`("Y@@!PXV#0&``$N00`D^.0T"``@+F``'OC8/#0``BY@``8N0@`:KF!
M`!?K60`%``WK>0`;``SKH``>``WK```"``RY@0!UN0@`%KF!`*#C`-`8``2Y
M&@`7XP#PV``(IWG__^.@T"``@+F"`'FY!`!@N00``>,`T"``@+F``'BY@``Z
MN00`5KD(`%NY@0`WZV``!0`-ZW``&P`,Z[D`'@`-ZYD``@`,N8$`=KD(`#6Y
M@0"YXY#0&``$N1H`-^.0\.``"*=Y___CL-`@`("Y@@!PN00`:;D$`)/CD-`@
M`("Y@`!ZN8``&[D$`%:Y"`!8N8$`%^MI``4`#>MY`!L`#.N``!X`#>L```(`
M#+F!`':Y"``5N8$`@.,`T!@`!+D:`!?C`/#H``BG>?__XX#0(`"`N8(`>;D$
M`&"Y!``!XP#0(`"`N8``>[F``#BY!`!6N0@`6KF!`#?K8``%``WK<``;``RY
M@0!VN0@`->NI`!X`#>N9``(`#+D:`#>Y@0"IIWG__^.@T"``@+F"`'#C8-`8
M``2Y!`"3XY#0(`"`N8``>.-@\/``"+F``!JY"`!KN8$`%^M9``4`#>MY`!L`
M#+F!`'6Y"``6Z[``'@`-ZP```@`,N1H`%[F!`+"G>?__X[#0(`"`N8(`>>-@
MT!@`!+D$``'C`-`@`("Y@`!ZXV#P^``(N8``.[D(`&BY@0`WZU``!0`-ZW``
M&P`,N8$`=;D(`#;KB0`>``WKF0`"``RY&@`WN8$`B:=Y___C@-`@`("Y@@!P
MXV#0&``$N00`D^.0T"``@+F``'OC8/$```BY@``8N0@`:KF!`!?K60`%``WK
M>0`;``SKH``>``WK```"``RY@0!UN0@`%KF!`*#C`-`8``2Y&@`7XP#Q"``(
MIWG__^.@T"``@+F"`'FY!`!@N00``>,`T"``@+F``'BY@``ZN00`5KD(`%NY
M@0`WZV``!0`-ZW``&P`,Z[D`'@`-ZYD``@`,N8$`=KD(`#6Y@0"YXY#0&``$
MN1H`-^.0\1``"*=Y___CL-`@`("Y@@!PN00`:;D$`)/CD-`@`("Y@`!ZN8``
M&[D$`%:Y"`!8N8$`%^MI``4`#>MY`!L`#.N``!X`#>L```(`#+F!`':Y"``5
MN8$`@.,`T!@`!+D:`!?C`/$8``BG>?__XX#0(`"`N8(`>;D$`&"Y!``!XP#0
M(`"`N8``>[F``#BY!`!6N0@`6KF!`#?K8``%``WK<``;``RY@0!VN0@`->NI
M`!X`#>N9``(`#+D:`#>Y@0"IIWG__^.@T"``@+F"`'#C8-`8``2Y!`"3XY#0
M(`"`N8``>.-@\2``"+F``!JY"`!KN8$`%^M9``4`#>MY`!L`#+F!`'6Y"``6
MZ[``'@`-ZP```@`,N1H`%[F!`+"G>?__X[#0(`"`N8(`>>-@T!@`!+D$``'C
M`-`@`("Y@`!ZXV#Q*``(N8``.[D(`&BY@0`WZU``!0`-ZX``&P`,N8$`A;D(
M`#;K>0`>``WKF0`"``RY@0!YN1H`.*>9___C<-`@`("Y@@"0XV#0&``$N00`
M@^.`T"``@+F``)OC8/$P``BY@``7N0@`:KF!`!GK6``%``WKF``;``RY@0"5
MN0@`%NN@`!X`#>L```(`#+F!`*"Y&@`9IVG__^.@T"``@+F"`&CC`-`8``2Y
M!`"1XY#0(`"`N8``9^,`\3@`"+F``#JY@0`VN0@`"^M9`!L`#.MI``4`#;F!
M`&6Y"``#Z[@`'@`-ZX@``@`,N1H`!KF!`+CC8-`8``3C8/%```BY!`"+ISG_
M_^.`T"``@+F"`#FY!`!6N00`8.-@T"``@+F``#JY@``8N8$`$^LV``4`#;D(
M`'6Y!`!3ZS8`&P`,N8$`-;D(`!>Y!`!3ZWD`'@`-ZSD``@`,N8$`<[D:`!7C
M,-`0``2Y@@"WXS#Q2``(N00`D>.0T"``@+F"``NY"`"CN00`6;D:`*#KN0`%
M``WKF0`;``RY@0"YZS8`'@`-N00`"NMF``(`#+F!`&.Y&@`+XS#0$``$N00`
MM[F"`+;C,/%0``BY!`"@XZ#0(`"`N8(`&[D(`(.Y&@"!ZYH`&P`,Z[H`!0`-
MN8$`N;D$`#BY&@`[ZQ4``@`,ZY4`'@`-N8$`D;D$`+/C$-`0``3CL-`@`(#C
M$/%8``BY&@`7N00`AKF"`(FY@@`(ZWL`&P`,ZXL`!0`-N8$`A[D:`!#K"@`>
M``WKJ@`"``RY@0"@N1H`&.-PT!``!+D$`(GC</%@``BY@@"*N00``>,`T"``
M@+F"`(.Y!``WN1H`-NMP``4`#>M@`!L`#+F!`':Y&@`XZXL`'@`-Z[L``@`,
MN8$`B[D:`#>Y!`!JXW#0$``$XW#Q:``(N8(`:+D$`+/CL-`@`("Y@@!AN00`
M%[D:`!GK>P`%``WKFP`;``RY@0!YN1H`%NN0`!X`#>L```(`#+F!`)"Y&@`7
MN00`:.-PT!``!.-P\7``"+F"`&FY!``!XP#0(`"`N8(`8[D$`#>Y&@`ZZW``
M!0`-ZZ``&P`,N8$`>KD:`#;KJP`>``WKNP`"``RY@0"KN1H`-[D$`&GC<-`0
M``3C</%X``BY@@!JN00`L^.PT"``@+F"`&&Y!``7N1H`&.M[``4`#>N+`!L`
M#+F!`'BY&@`6ZX``'@`-ZP```@`,N8$`@+D:`!>Y!`!JXW#0$``$XW#Q@``(
MN8(`:+D$``'C`-`@`("Y@@!CN00`-[D:`#GK<``%``WKD``;``RY@0!YN1H`
M-NN;`!X`#>N[``(`#+F!`)NY&@`WN00`:.-PT!``!.-P\8@`"+F"`&FY!`"S
MX[#0(`"`N8(`8;D$`!>Y&@`:ZWL`!0`-ZZL`&P`,N8$`>KD:`!;KH``>``WK
M```"``RY@0"@N1H`%[D$`&GC<-`0``3C</&0``BY@@!JN00``>,`T"``@+F"
M`&.Y!``WN1H`..MP``4`#>N``!L`#+F!`'BY&@`VZXL`'@`-Z[L``@`,N8$`
MB[D:`#>Y!`!JXW#0$``$XW#QF``(N8(`:+D$`+/CL-`@`("Y@@!AN00`%[D:
M`!GK>P`%``WKFP`;``RY@0!YN1H`%NN0`!X`#>L```(`#+F!`)"Y&@`7N00`
M:.-PT!``!.-P\:``"+F"`&FY!``!XP#0(`"`N8(`8[D$`#>Y&@`ZZW``!0`-
MZZ``&P`,N8$`>KD:`#;KJP`>``WKNP`"``RY@0"KN1H`-[D$`&GC<-`0``3C
M</&H``BY@@!JN00`L^.PT"``@+F"`&&Y!``7N1H`&.M[``4`#>N+`!L`#+F!
M`'BY&@`6ZX``'@`-ZP```@`,N8$`@+D:`!>Y!`!JXW#0$``$XW#QL``(N8(`
M:+D$``'C`-`@`("Y@@!CN00`-[D:`#GK<``%``WKD``;``RY@0!YN1H`-NN;
M`!X`#>N[``(`#+F!`)NY&@`WN00`:.-PT!``!.-P\;@`"+F"`&FY!`"SX[#0
M(`"`N8(`8;D$`!>Y&@`:ZWL`!0`-ZZL`&P`,N8$`>KD:`!;KH``>``WK```"
M``RY@0"@N1H`%[D$`&GC<-`0``3C</'```BY@@!JN00``>,`T"``@+F"`&.Y
M!``WN1H`..MP``4`#>N``!L`#+F!`'BY&@`VZXL`'@`-Z[L``@`,N8$`B[D:
M`#>Y!`!JXW#0$``$XW#QR``(N8(`:+D$`+/CL-`@`("Y@@!AN00`%[D:`!GK
M>P`%``WKFP`;``RY@0!YN1H`%NN0`!X`#>L```(`#+F!`)"Y&@`7XV#0$``$
MN00`>.-@\=``"+F"`'FY!``!XP#0(`"`N8(`<[D$`#:Y&@`ZZV``&P`,ZZ``
M!0`-N8$`IKD:`#?K>P`>``WKNP`"``RY@0![N1H`.N.PT!``!+D$`*GCL/'8
M``BY@@"GN8(`H;D$`!NY&@`8N00`8^-@T"``@+D:`!KKH``>``WK```"``RY
M@0"@ZX8`&P`,Z[8`!0`-N00`![F!`+BY@@`*N1H`&[D$`+#C`-`0``3C`/'@
M``BY!`"!N00`6^.`T"``@+F"`%.Y!``PN1H`.>L(``4`#>N8`!L`#.NV`!X`
M#>MF``(`#+F!`+:Y@0`)N1H`-;D$`&JY&@`PN8$`:[F``&&Y!``*XQ#0"``$
MN00`D^.0T"``@+F```OC$/'H``BY@0!@N1H`%^M9`!L`#.MY``4`#;F!`'6Y
M&@`6ZP@`'@`-ZX@``@`,N8$`"+D:`!>Y!`![N8$`<+F``'.Y!`!KXS#0"``$
MN00`@>.`T"``@+F``&#C,/'P``BY@0!VN1H`.NM8`!L`#.MH``4`#>NI`!X`
M#>N9``(`#+F!`*FY@0!EN1H`-[D$`'"Y&@`VN8$`>KF``'&Y!`!@XQ#0"``$
MN00`D^.0T"``@+F``&KC$/'X``BY@0!VN1H`&^M9`!L`#.MI``4`#>NX`!X`
M#>N(``(`#+F!`+BY@0!EN1H`%[D$`'JY&@`6N8$`>[F``'.Y!`!JXS#0"``$
MN00`@>.`T"``@+F``&OC,/(```BY@0!VN1H`,.M8`!L`#.MH``4`#;F!`&6Y
M&@`WZPD`'@`-ZYD``@`,N8$`";D:`#:Y!`!KN8$`8+F``&&Y!`";XQ#0"``$
MN00`<^-PT"``@+F``)#C$/((``BY@0!IN1H`&NM7`!L`#.NG``4`#;F!`*6Y
M&@`6ZY@`'@`-ZX@``@`,N8$`F+D:`!KC@-`(``2Y!`"@N8$`J>.`\A``"+F`
M`#JY!`!HN00`H+F``*FY!`"!N00`5N.`T"``@+F!`#JY&@!;ZV@`&P`,N1H`
M4^NX``4`#>NG`!X`#>MW``(`#+F!`*>Y@0"VN00`-;D$`'FY&@`[N8$`>N.P
MT`@`!+F``''CL/(8``BY!`!IN00`$^,0T"``@+F``&JY&@"PN8$`=NM1`!L`
M#+D$``OK80`%``WKN``>``WKB``"``RY@0"XN8$`9;D:``>Y!`"*N1H`!KF!
M`(NY!`!8N00`@..`T"``@+F``%/K80`>``VY!`!ZXS#0"``$ZQ$``@`,N8$`
M%KF``'OC,/(@``CK:``;``RY@0!UN1H`.;D$`%;KF``%``VY@0!9N00`F[D:
M`#>Y@0"1N1H`-;F``)"Y!``+N00`<[F```'C,-`(``2Y@0`)XS#R*``(N00`
ME^.0T"``@+D:`#JY&@`PZZD`!0`-ZPD`&P`,N8$`"NNH`!X`#>N(``(`#+F!
M`(JY!`!AN1H`,+F!`&BY@`!GN00`H>,`T`@`!+D$`'/C<-`@`("Y@`"HXP#R
M,``(N8$`:KD:``OK5P`;``SKMP`%``WKJ0`>``WKF0`"``RY@0"IN8$`M;D:
M``:Y!`!HN1H`"[F!`&JY@`!CN00`N.,PT`@`!+D$`)#CD-`@`("Y@`"ZXS#R
M.``(N8$`:[D:`#'K60`;``SK&0`%``WKMP`>``WK=P`"``RY@0"WN8$`%;D:
M`#:Y!`!JN1H`,;F!`&NY@``&XQ#0"``$N00`:KD$`'/C<-`@`("Y@`!KXQ#R
M0``(N8$`8+D:`!CK5P`;``SKAP`%``VY@0"%N1H`%NL)`!X`#>N9``(`#+F!
M``FY&@`8N00`B[F!`("Y@`"#N00`:^,PT`@`!+D$`)'CD-`@`("Y@`!@XS#R
M2``(N8$`AKD:`#KK60`;``SK:0`%``WKIP`>``WK=P`"``RY@0"GN8$`9;D:
M`#BY!`!PN1H`-KF!`'JY@`!QN00`8.,0T`@`!+D$`(/C@-`@`("Y@`!JXQ#R
M4``(N8$`=KD:`!OK6``;``SK:``%``WKN0`>``WKF0`"``RY@0"YN8$`9;D:
M`!>Y!`!ZN1H`%KF!`'NY@`!SN00`:N,PT`@`!+D$`)'CD-`@`("Y@`!KXS#R
M6``(N8$`=KD:`##K60`;``SK:0`%``VY@0!EN1H`-^L(`!X`#>N(``(`#+F!
M``BY&@`VN00`:[F!`&"Y@`!AN00`>^,0T`@`!+D$`(/C@-`@`("Y@`!PXQ#R
M8``(N8$`9[D:`!KK6``;``SKJ``%``WK>0`>``WKF0`"``RY@0!YN8$`I;D:
M`!:Y!`!@N1H`&KF!`&>Y@`!CN00`H.,PT`@`!+D$`)'CD-`@`("Y@`"GXS#R
M:``(N8$`:KD:`#OK60`;``SKN0`%``WKJ``>``WKB``"``RY@0"HN8$`M;D:
M`#:Y!`"'N1H`.[F!`(KCL-`(``2Y@`"!X[#R<``(N00`9[D$`!/C$-`@`("Y
M@`!JN1H`L+F!`(;K40`;``RY!``+ZV$`!0`-Z[D`'@`-ZYD``@`,N8$`N;F!
M`&6Y&@`(N00`BKD:``:Y@0"+N8``@[D$`&KC,-`(``2Y!`"0XY#0(`"`N8``
M:^,P\G@`"+F!`(:Y&@`WZUD`&P`,ZWD`!0`-N8$`=>MA`!X`#;D:`#CK$0`"
M``RY@0`6N1H`-[D$`'NY@0!QN8``<+D$`&OC`-`(``2Y!`"#XX#0(`"`N8``
M8>,`\H``"+F!`':Y&@`*ZV@`&P`,ZZ@`!0`-N8$`IKD:``>Y!`!ZZZD`'@`-
MZYD``@`,N8$`FKD:``?C8-````2Y!`!QXV#RB``(N8(`>;D$`*#CH-`@`("Y
M@@!SN00`-KD:`#OK:@`;``SKN@`%``VY@0"VN1H`-[D:`#OK>``>``WC8-``
M``3KB``"``RY@0!XXV#RD``(N00`B;D$`+/CL-`@`("Y@@"'N1H`8;F"`("Y
M!``6ZPL`!0`-ZVL`&P`,N8$`!KD:`!CKB@`>``WKJ@`"``RY@0"*N1H`$+D$
M`&?C`-````3C`/*8``BY@@!HN00`H>.@T"``@+F"`&.Y!``PN1H`.>L*``4`
M#>N:`!L`#+F!``FY&@`VZYL`'@`-Z[L``@`,N8$`F[D:`##C8-````2Y!``(
MXV#RH``(N8(`";D$`+/CL-`@`("Y@@`!N00`%KD:`!?K:P`;``SK>P`%``VY
M@0!VN1H`$.L*`!X`#>NJ``(`#+F!``JY&@`7N00`:>-PT```!.-P\J@`"+F"
M`&"Y!`"AXZ#0(`"`N8(`8[D$`#>Y&@`XZWH`!0`-ZXH`&P`,N8$`>+D:`#;K
MBP`>``WKNP`"``RY@0"+N1H`-[D$`&#C<-````3C</*P``BY@@!HN00`L^.P
MT"``@+F"`&&Y!``7N1H`&>M[``4`#>N;`!L`#+F!`'FY&@`6ZYH`'@`-ZZH`
M`@`,N8$`FKD:`!>Y!`!HXW#0```$XW#RN``(N8(`:;D$`*'CH-`@`("Y@@!C
MN00`-[D:`##K>@`%``WK"@`;``RY@0!PN1H`-NL+`!X`#>N[``(`#+F!``NY
M&@`WN00`:>-PT```!.-P\L``"+F"`&"Y!`"SX[#0(`"`N8(`8;D$`!>Y&@`8
MZWL`!0`-ZXL`&P`,N8$`>+D:`!;KB@`>``WKJ@`"``RY@0"*N1H`%[D$`&#C
M<-````3C</+(``BY@@!HN00`H>.@T"``@+F"`&.Y!``WN1H`.>MZ``4`#>N:
M`!L`#+F!`'FY&@`VZYL`'@`-Z[L``@`,N8$`F[D:`#>Y!`!HXW#0```$XW#R
MT``(N8(`:;D$`+/CL-`@`("Y@@!AN00`%[D:`!#K>P`%``WK"P`;``RY@0!P
MN1H`%NL*`!X`#>NJ``(`#+F!``JY&@`7XV#0```$N00`>>-@\M@`"+F"`'"Y
M!`"AXZ#0(`"`N8(`<[D$`#:Y&@`XZVH`&P`,ZXH`!0`-N8$`ANMK`!X`#>N[
M``(`#+F!`&NY&@`WN00`L+D:`#BY@@"VXW#0```$XW#RX``(N00`B[D$`+/C
ML-`@`("Y@@"!N1H`>;D:`'CKFP`;``SK&P`%``VY@0`9N00`A[D:`('KF@`>
M``WC<-````3KJ@`"``RY@0":XW#RZ``(N00`IKD$`!CC$-`@`("Y@@"IN1H`
M<+F"`*.Y!``'ZS$`!0`-ZW$`&P`,N8$`-[D:``JY&@`#ZZL`'@`-Z[L``@`,
MN8$`J[D$`'GC,-````2Y!`"PX[#0(`"`N8(`>N,P\O``"+F"`'BY&@`VZUL`
M&P`,ZXL`!0`-N8$`A;D:`#>Y&@`XZV$`'@`-XX#0```$ZQ$``@`,N8$`%N.`
M\O@`"+D$`'JY@@!QN1H`B;D$`&/C8-`@`("Y@@`'N00`F+D:`)#KA@`%``WK
M!@`;``RY@0"`N1H`F.L+`!X`#>N[``(`#+F!`+"Y!`!QN00`B>,`T```!..`
MT"``@+F"`'OC`/,```BY@@!SN1H`"NLX``4`#>NH`!L`#+F!`#JY&@`'N1H`
M`^MV`!X`#>MF``(`#+F!`':Y!`"KN00`8.,PT```!.-@T"``@+F"`*?C,/,(
M``BY@@":N1H`,>NF`!L`#.L6``4`#;F!`!JY&@`YN1H`,>N8`!X`#>,0T```
M!.N(``(`#+F!`)BY!`"GXQ#S$``(N00`@^.`T"``@+F"`*FY&@`;N8(`"KD$
M`+'KJ``;``SK&``%``VY@0`:N1H`L.NF`!X`#>MF``(`#+F!`*:Y&@"QN00`
M:>,0T```!+F"`&KC$/,8``BY!``+XP#0(`"`N8(`-KD:`!?K8``%``VY&@`3
MZW``&P`,ZS@`'@`-ZX@``@`,N8$`.+F!`':Y!`!JN8(`8[D:`!>Y!`!SXS#0
M```$XS#S(``(N8(`MKD:`#GC$-`@`("Y&@`[LD\`@.NP`!X`#>L```(`#+F!
M``OK80`%``WKD0`;``SCL"`@``3KB``@``VY&@"ZN8$`EN.@(!@`!+)/`(&Y
M&@`YN1H`I^-0\*``!.,0(`@`"+D:`$.Y&@!0N00`.N.PT"``@.,0T"``@.,P
MT"``@.-`T"``@.-0T"``@..P("``).,0(`@`).,P(!@`).-`(```).-0(!``
M)-4'\RB`**=T``GC0/.@``3K;_-@``0'],#E___LA`<'ZV_P,``DI_O_8+D"
M`(*GA`!OP!```$7?XQ`0```$XV`0```$N0(`9J>$`&+C$(```)`2$:>$`%BG
M'@`]IX0`5+D$`)A!D)`!XQ"0``"0$A&GA``&IQX`/:=T__8;F..P8```!+D"
M`+NGA``CN00`<[D4`)FY!`"FN00`2;D$`#BY!``KP.7__^[.$B*G=``(01FP
M`)4]$`"GA``40:"@"..PH```!+D"`+NG=/_GXT#Q$``$N00`*^MO\-``!`?T
MN0D`INL:``,`"E`0<`!!N;`!XT#Q$``$N00`*^MO\-``!`?TIY@``*?T_[NG
MN0``I_3_WP<'!P>R3P`0ZQ$`(``-ZZ_P4``DLD\`$:?[_U"Y!`"B0;#PI-('
M\*@0*+D$`#NY!``JP.7___]MN0(`(J>$`#+`(```14[C$/"D`!3C("````3K
M$0`#``WC$"````CC(!`(``3C(!```"2Y`@`BIX3_WD$0$`CC(!`(``3C(!``
M`"2Y`@`BIW3_]KD$`#NY!``JP.7___\]N0(`(J=T_]*R3P`0ZQ$`(``-LD\`
M$=4'\*@0**=T``GC0/$@``3KK_$```0'],#E___KH^MO\#``),#0```12:?[
M_SBR3P`0ZQ$`(``-LD\`$;D$`*/C,#```)!7,-`,IT@``!]#XZ#0``"(T@?P
MP!`HN00`&J<(``!!,/"\IYD``+D$`+*R7@"1IQ3__L#E___^\[D)`)JY`@`B
MIX0`JKD$`#*G"```IQD``+)>`!.G%/_^N0D`$KDA`)&GQ`"+XX#PO``4ZX@`
M`P`-P&```$2\XQ"P``"0$A&GA`$5IQX`/:>$`1&Y!``;I_0`!J<N`#VGA``*
M01`0`>,@$```D!(BIW3_]KD)`!NY%``1XW!@```$02D0`N.`<```",#E___K
M^^,@@```)+D"`"*GA`#UXR#PO``4ZR(``P`-XS!P```$XQ"P``"00;"P`>,B
M,```!$(0(`!4$-`(IW0`$:?T`!-!("`!XQ"P``"00A`@`%00T`BGA``(I[L`
M`:<>`#VG=/_QDCT@`*<9``#C,:```)!",2`!IQL``;D"`#.G=/_WIR@``+)/
M`!#K$0`@``VR3P`1N10`(M4'\,`0**=T`+#C4/$X``3K;_#X``0']:<9``#C
M,:```)!",2``IQL``;D"`#.G=/_WI_3_W,!@``!$*N,08```!.,@$```!.,@
M\*@`)-4'T``@`*>$`'^Y!``2IR@``*?T``,8)T$0$`@8<J=Z``'5!]``$`"G
M=/_WIRH``[D4`"+K(@`#``W`$```3&6_/Q``IX0`,[D$`#+C(/"H``3`Y?__
MZJWC$&````2Y`@`BXR`0```DIX0`5+D4`!?C$/"P`"3C(/"@`"3K@0`#``WC
M$/"P``2G&P`!ZQ$``P`-XR#PH``$ISD``.,Q(```)%!P\+RG]/\2IS@``5`P
M$`#`Y?__ZRVY`@`2XQ#PH``DIX0`)[D4`#?K@P`#``WC,/"P`"2Y!`!(XS#P
MJ``$P.7__^GFXQ!@```$XR#PH``$XR`0```DI_3_Q:<9``"G]/\#IRD`$*=X
M``"G]/^7IRC__Z?T_T;`Y?__ZBH'!P<'!P>R3P`0ZQ$`(``-ZV_P,``DLD\`
M$:?[_L"Y`@"2T@?Q.!`HIX0`!I4`D`"G=``5LD\`$.L1`"``#;)/`!'5!_$X
M$"BG=`"FXT#QL``$ZV_Q<``$!_3`Y?__[.JY`@""IX3_Z*>H`"Y!</"HN00`
M*,#E___L;;D"`+*GA``@XQ"P$P"0&"H?(:=4`"7C$+`4`)`2$:>$_^P8*A\A
MIZ0`<!,2$A&G=``:N00`*,#E___L3[D"`+*G=/_DN00`*,#E___LEKD$`"G`
MY?__Z9&G]/^Q$B*GA/_,N00`&4&PL!.Y!``[IP@``*<I``"R7@`AIQ3__J<9
M``"R7@`3IQ3__KD)`!NY"0`I&B&G*@`"N10`(L#E___J;+D$`&G`4```#\NG
M2?__ISD``>.P\*``)+D$`-+`Y?__ZONY!`!'N00`/:<I``'`Y?__["*G+O__
MN00`+:>$``JE'_``5!#PP*<>0`"GA``1P.7__^HQN00`+<#E___I'*?T_WKC
M$+`5`)"G]/^0P.7___\^I_3_\<#E___I70<'!P?KK_!0`"3`T```#PFG^_]@
MP!```$*0N00`HN.P$```!.,@L```%L#E___K]:<K`?BY!`!"N00`.J<I``'`
MY?__Z_H2(J>$``VG*```XT#Q$``$N10`(NNO\/``!`?TXR"P```6P.7__^O6
MI1_P`%00(A"G'D``IX0`$.,@L```%L#E___KR*4?\`!4$"(061#0`*=T_]NY
M!``JISD``L#E___K.1`BIRK__X@@`!_C0/$0``2Y%``BZZ_P\``$!_3KC_!`
M`"2R3P`0I_OO6*=9$*#K$0`@``VR3P`1N00`DD&P\*!!5?``N00`@Z=)#_^Y
M!``[P"````\5T@=0`!`HP.7__^E($B*GQ`!.&!*G&O__N10`H>,Z\*``D*<Q
M`/^GA``_N10`HKD$`$JG.0`ON00`*\#E___J?KD"`"*GA``SP!```$'WXQ`0
M```$XR`0```6P.7__^M>N00`6KD$`$NY!``YP.7__^L%LD\`$*<I$*#K$0`@
M``VR3P`102+P`-4'(``0**=T`".G^Q"HXT#P<``$ZX_P0``$!_02$:=T_\3`
M$```0<;C$!````3C(!```!;`Y?__ZRVY!`!(N00`.<#E___HMJ?T_]'`Y?__
MZ'$'!P<'P!```$&LZ^_P<``DXQ`0```$I_O_8.,@$```%L#E___K#L`0``!!
ME\!0```.A.-`$```!,`P```.D>OO\1``!,#T___IW`<'P!```$&(ZV_P,``D
MXQ`0```$I_O_6,!@```/_>,@$```%L#E___JY\#E____R,`0``!!<>,0$```
M!.,@$```%L#E___JV*<9``#C$/"@`"2Y!`!6P$````J:P#````YHP.7__^HX
MXT#Q&``$ZV_PV``$!_0'!P<'ZV_P,``DLD\`$*?[WTBG*2"PZQ$`(``-LD\`
M$4&P\*Y!(O``T@<@`!`HP.7__^BGP!````Y2N00`8N,0\*``)+D$`"O`4```
M#D*G21`!ISD``<#E___I4Q(BIT0`8+D$`*^GJQ"ON00`*[D$`#JG21``P.7_
M_^A#$B*Y!`"RIT0`3J<J``&Y%``BP.7__^B7N0(`(J>$``NY%`"[$KNG=``?
M01L@`)(`$`"R3P`0ISD@L.L1`"``#;)/`!%!,_``U0<P`!`HIW0`+J?[(+CC
M0/!P``3K;_`P``0']!@[ISK__Q@3B!``"!(1N00`0J=T``O`$````!NY%@`S
M1#`0`*?T_]'2_T``H`!!0$$`0:"A`*<6__FG]/_NIRD``*?T_\;`Y?__YWO2
M`$``H``'!\#T____:`<'ZV_P,``DP-````TEI_OO0+)/`!"G21"XZQ$`(``-
MLD\`$;D$`**Y!`"S043P`$$P\+3`(```#;C2!T``$"C`Y?__^M&G.0`ON00`
MDKD$`"K`Y?__Z%BY`@`BIX0`);D$`#K`(```#:7`Y?__^YRY!``JLD\`$*<Y
M$+CK$0`@``VR3P`103/P`-4',``0**=T`.6G^Q#`XT#P<``$ZV_P,``$!_2Y
M!``:IP@``+D$`"NG>0``P#````V#LEX`<:<4__[`Y?__Z4\;>KD"`"*GA/_(
MIWH``94`(`"GN?``08#PN*>$`(JY`@"9IX0`#KD$`!*Y!``YIP@``+)=`!.G
M%/_^IX0`:KD$`#*G"```IQD``+)>`!.G%/_^N0D`$KD$`#*Y&``Q03.__Y4O
M,`"G=``0IQK__[D4`#%!0R``032__Y(`0`"5+S``IX3_]!H7IQX/_Z<D_X7`
M$```#3*Y!`!BP%````VZITD0`*<Y``'C$/"@`"3CH/"H`"2Y!``HP.7__^@@
MP!```#_MXV`0```$XR!@```6P.7__^E4IRL!^+D$`$*Y!``XIRD``<#E___I
M.1(BIW0`$.,@8```%L#E___I0*4?\`!4$"(061#0`*>$`"K`,```#/*G*0``
MP.7__^C`N0(`(J>$_SJ5`"``IW3_>KD"`)FGA``/N00`*<`0```,SZ<(``"R
M70`2IQ3__J>$_^'`(```#,2G&``!I_3_EJ<Y``&Y!``HP.7__^B)$B*G=/_0
MN00`.,`@```,M\#E___ZKKD$`"C`Y?__Y_FG]/\/P.7__^9$!P?`4```"_SC
M$"```)"Y`@`1!XX804$0(`&G]``,XS`0``"0IQL``;D"`#,80Z>$`!*]05``
MIW3_].,P$```D+D$`"&G&P`!N0(`,QA#IW3_\@?^!P<'!P<'Z]_P:``DP-``
M``O1I_O_8+D"`#*GA``RXR`P``"0N0(`(J>$`"NY!`!#IP@``*<9``"R7@`4
MIQ3__J<;__^Y(0`QIZ0`1Y4O$`"G=``ON00`0;D)`$.G&___IT<`(Z<O`"^G
MA``+P"````Q/Z]_Q"``$P/3__^>+IRD``L#E___FIKD"`"*GA`!HIQ@N`$`0
M(`#C0/$0``3KW_$(``0'])4O$`"GA/_9N00`0;D$`%&Y"0!#IUO__[DA`#6G
M)`!6IS___Z>$`%*G&___IT<`.;D@`#&GA/_%N00`0;D$`"&Y"0!#IRO__[DA
M`#*G)`!"IS___Z>$`#ZG&___IT<`)[D)`!.Y!``AIRL``N,@T```(:<D`")!
M0!`!IUD0`,`@```_4<#E___G<N-`\1``!,`@```_2.O?\0@`!`?TE2\0`*=T
M_\.G]/_)E2\0`*>$_]6G]/_7XT#Q$``$IRD``.O?\0@`!`?TITD``:?T_ZZG
M20`!I_3_PK)/`!#K$0`@``WKO_!8`"2R3P`1I_O_,,`P```+$,`@```+N-('
M\,@0*-(A\*8P`,#E___Y/,`@```+L<#E___Y-L`@```+K\#E___Y,,`@```+
MKL#E___Y*L`@```+K,#E___Y),`@```+KL#E___Y'L`@```+@,#E___Y&,`@
M```+J,#E___Y$L`@```+I\#E___Y#,`@```+IL#E___Y!L`@```+;<#E___Y
M`,`@```+G\#E___X^L`@```+GL#E___X]$&P\*"Y!``[P"````N:P.7___AN
MN0(`,J>$``C`(```"WO`Y?__^42Y!``[P"````N1P.7___A<N0(`,J>$``C`
M(```"Y#`Y?__^3*Y!``[P"````N.P.7___A*N0(`,J>$`"3`(```"R3`Y?__
M^2#`,```"Y7`(```"SO`Y?__^1>R3P`0ZQ$`(``-LD\`$=4'\,@0**=T`"[C
M0/%```3KO_$H``0']+D$`#O`(```"VC`Y?__^!RY`@`RIX0`"L`@```+),#E
M___X\J?T_]*G20`*P#````M=02#PM\#E___G%A(BIW3_Q4$P\,&G]/_IP.7_
M_^1\!P?KO_!8`"3`T```"DVG^_]0LD\`$.L1`"``#;)/`!'`L```/BE8(+``
MIR[__]('\*@0**>$`!>R3P`0ZQ$`(``-LD\`$;D4`"+5!_"H$"BG=``NXT#Q
M(``$Z[_Q"``$!_1!,/"DP"````K5P.7___?#N0(`(J>$`!7C("```)"Y`@`B
MIX0`#N,@T```@KD#`"+K(@`_``Q0(+``I_3_SJ<H``!0(+``I_3_R,#E___D
M(^OO\'``)*?[_V#`Y?__Y"O`Y?__XZBY`@`BIX0`#.,@(```!.-`\1``!.OO
M\1``!`?TIRD``*?T__<'!P<'!P>R3P`0ZQ$`(``-ZV_P,``DLD\`$:?[_P#`
M,```/6C2!_#X$"C2-_#`,`#CL/#```2Y`@"[IX0`1KD$`()!H/#(07#PO,#0
M```*2Z?T`!BY!``XP.7__^,WN0(`(J>$`$6GJP`(N00`&J<;__CCL!````2Y
M`@"[IX0`);D$`#>Y!``KP.7___<_N0(`DJ>$``:5`)``IW3_W;D$`"NY!``X
MP.7___@0IZL`"+D$`!JG&__XX[`0```$N0(`NZ=T_]^R3P`0ZQ$`(``-LD\`
M$=4'\/@0**=T`$'C0/%P``3K;_$P``0']+D$`!BY!``YIP@``+D$`&BR7@`A
MIQ3__J<9``"R7@`3IQ3__KD)`!FY"0`H02(0`L#E___D1>.0\*@`)./0\*``
M),!0```*9Z=)__^G.0`!XR#PL``DP.7__^32XS#PL``$N00`*\#E___WNJ?T
M_X?`Y?__XU4'!P<'ZV_P,``DP-````DIX_#0<``(LD\`$.L1`"``#;)/`!'C
ML-!H``3`4```/,W`,```/-9!N_`HP$```#SIT@>P`!`H0:#P[-(7\/!0`-(O
M\2`P`+D$`'*Y!``ZP"````F$TA?Q"$``P.7___:=N0(`LJ>$``:5`+``IW0"
M?\#E___^\KD"`)*GA`*$N00`&:<(``"G*0``LEX`(:<4__ZY"0`IZR(``0`-
MIRL``<#E___CRN,0D```D+D"`!&Y!`"R&&&GA``@N00`BU1@T("Y%`!FN00`
M*,!0```)W*=)__^G.0`!P.7__^1.09"0`>,0D```D+D"`!%!@(`"&&&G=/_F
MXR#Q(``$N0(`(J>$`"]!D/$HI_0`#Z>;``BY!``9IQO_^.,@$```!+D"`"*G
MA``>N00`.L#E___V-;D"`(*GA/_LE0"``*>$_^C`Y?__^5(2(J>$_^*Y!``H
MP.7__^12N0(`8J=T`#NGF```XX#08``$XR#06``$N10`&>L1``,`#4$B\"BY
M"``2XV&.V``$N0(`9J>$`"&5`&``IX0`';D$`";`Y?__^242(J=T``:GF@`!
MI_3_W[D$`";`Y?__Y"&GF@`!N0(`(J>$_]2Y!`!BI_0`!*=I``"Y!``6IP@`
M`*>9``"G*0``LEX`D:<4__ZY!``;N0D`EK)>`"&G%/_^N00`$KD)`!L:D:>:
M!`2Y%`"9N00`*<#E___C$\`0```)/\`P```(J^,P\,@`).,0\*@`).,P\*``
M),!0```)*Z=)__^G.0`!X[#PL``DN00`@L#E___CE;D$`"BG.0'`P.7__^.^
MIR[__Z>$`%+`$```.U?C8!````3C(&```!;`Y?__Y+ZG*P'XN00`0KD$`#BG
M*0`!P.7__^3#$B(8LJ>$`%_`$```.S2Y!`!HXQ`0```$XU!P```$P$````DO
MXR`0```$ISD``<#E___C^:>9``"R3P`0ZQ$`(``-LD\`$>,PT&@`!+D$`"E!
M,_`HU0<P`!`HIW0$0N/PT%``".-`\'``!.MO\#``!`?TP.7__^,G6!`@`*<>
M`!&GA/^IP"```#KVN10`$>,@(```!.,0\*``)+D$`&CC4'````3C("````3`
M0```"*VG.0`!P.7__^.VIYD``*?T_[WC(&```!;`Y?__Y$RE'_``5!`B$*<>
M0`"G=/^7XR!@```6P.7__^0^6!`B%%`0\,#`Y?__X9=9(/#`IW3_AN,@8```
M%L#E___D+:<8`?]4$"(0IQX!P*=T_WBY!``IP.7__^)`N00`.KD$`)+`(```
M"%G`Y?__].:Y`@`BIX0!#..@<```!,#E___C#+D$`#*Y!``JP.7___GEN0(`
MHJ>$`/NY!``JIP@``*<9``"R7@`2IQ3__KD)`!JG'@`#I\0`);D4`"&G*__\
MP#````A:02*@`+)=`#*G%/_^IW0`%J<>``2GA`,`IQK__+D$`"JY&``AN00`
M$J<I\`!!$A__E2\0`*>$`O#`Y?___*,2(J=T``^Y!``JISD``,#E___B41(B
MN00`HAARIW0`NL`P```'X,`@```'E,#E___U8L#E___AK\"@```(O.-P\,@`
M!.,@\*@`).-P\*``)..@\+``)+D$`&C`4```"!FG2?__ISD``;D$`"G`Y?__
MXE*G]``KP.7__^(]U0/0?"``IW0`+L#E___AA:>Z``&Y%``;XR#PJ``DXZ#P
MN``DXW#PH``DXQ#PL``DN00`:,!0```']:=)__^G.0`!N00`*<#E___B)Z<Y
M`<"Y!``IP.7__^)0IR[__Z>$_\ZY!``HP.7__^!7N00`.<`@```'`\#E___T
M_[D$`"G`Y?___)JG]/ZSP.7___R5N00`*\#E___B0+D$`)*G]/ZG0;#Q"-4'
MT$BP`*>$`"&Y!``ZXR"P```$P.7___/]N0(`$J>$``:5`!``IW0`!J>[``BG
M]/_IP.7__^(>N0(`(J>$__>Y!`"2I_3]6J<I``W`Y?__X3&G:`!3N00`LL"0
M```'3:?T_6KCH'````2G]/\$ITD``J<Y_^[`Y?__X-Q!$/(0N00`,:=)``:Y
M!``JXQ#PP``DP.7__]^^E0#R$*=T``:50_(1IX0"8+D4`!>Y!``JITD``*<Y
M``#C$/#0`"3`Y?__X+A!$/&(XQ#PV``DXQ#00``$XQ#Q4``DXQ#0.``$XQ#Q
M6``DXQ#0,``$XQ#Q8``DXQ#0*``$XQ#Q:``DXQ#0(``$XQ#Q<``DIQD``.,0
M\7@`).,0\8``)%`0\<A!8/%0XY#PX``DXS#PP``$I4^``.,@\-``!,#E___?
M:Q(BN00`,AB2I\0`H;D4`"/C0/%X``3K$@`#``VY"``4XQ#0&`"`N2$`0>-`
M\8``!*?$``2G2P`!ZR(`'0`,N0@`).,0\7@`).,@\8``)+\?\<BGA`!WIR@`
M0!LA&3(80Z?$``,80N,@\-@`!+D8`"&Y%`"TN0(`N[D$`!*GA``>N00`JZ>K
M___K*@`(``RY`@`BXU#PP``$IX0`"]+_$`!0`$$0$0!!4%$`IR?_^<`@```"
M`T2@(``8%%H0\<A0$/'(IQX`0*=T_Y(8D[D$`"8;E..P\,``",#E___DH*>>
M`#^GQ``?&'FG>O_`B'``!KD$`*?CH-`0`("GJP`!N00`)M(_\8BP`$&PL$#`
MY?__Y(:GI__VIYK_P(EP``8;E[D$`#NG60!(N10`2>,@\-@`!,#E___@/U"0
M\<BG]/]7X[#PP``$I_3_S.,@\-``!..0\.``!,#E___B'>.P\7@`!.LK``,`
M#%0@T'BY%``2IRH``>.@\8``!*<N`#A!$?&(DH`0`*<D`2*G.``XXQ#PV``$
MN1@`$ALR$C,8(Z>$`!BG*O__&#*(,``($C.GA``)U_\0`!``01`1`*<V__O`
M,````7VY%@`B1"`P`.LZ`!@`#.L:`!``#+D$`"9"H/'#0K#QQ^NJ``@`#$(P
M\<!"$/'!ZSL`&``,ZQL`$``,Z[L`"``,0J#QPD(P\<1"$/'%0K#QQL#E___D
M`>,0\5``!.,P\5@`!.M!``@`#$)`\=7K0P`8``SC(/%@``1",/':0D#QU^M#
M`!``#.LS``@`#$(P\=GK,@`8``SK80`8``SK40`0``Q"$/'60B#QWN,0\6@`
M!$(P\=OK,@`0``SK(@`(``Q"0/'80C#QW.-`\7``!.LQ`!@`#$(@\=U"$/'B
MZR$`$``,ZQ$`"``,0C#QWT(@\>#K-``8``SK)``0``Q"$/'AZQ0`"``,0F#Q
MTT)0\=1"0/'F0C#QXT(@\>1"$/'E0:#QYT%P\=2GN0`45&#0@+D$`"JY%`!F
MP%````5AITG__Z<Y``'`Y?__W].GJP`"I[<`*^,@T%@`!,`0```&&>,0\+``
M)$$B\"CC(-`(``CC(/"H`"3C(/#(``3C(/"@`"2Y!`!HP%````5IITG__Z<Y
M``&Y!``ID@#R#\#E___?J*?T_8Q#8'``IWL``:?T_[_C$'`(``2Y`@`1IX3]
M#;D$`#&G"```IRD``+)>`".G%/_^N0D`(>,@T```(:?$_/RG*__\01(0`,`@
M```%-+)=`"&G%/_^IW3\[^.@<`@`!*?T_.JG&`!`XS#PV``$N1@`,AL2$A&G
MA``;IQK__QA!B$``"!)$N00`(Z>$``H8--?_(``@`$$@(0"G-O_[P#````!>
MN18`$400,`"Y!``FP.7__^,!US?QB/&(I_3^UI5!\A*G=/V@E4/R$Z=T_9R5
M2/(4IW3]F)5%\A6G=/V4ITD``J<Y_\:Y!``JP.7__]Y/X[#PP``$N00`.[D$
M`"JG20`IP.7__]TSXR#PR``$P!````5MXR#PH``DX[#PJ``DXQ#PL``DN00`
M:,!0```$Q:=)__^G.0`!N00`*<#E___?!J?T_.K`Y?__W9'2`!``4`#7`!``
M$`#7`"``(``'!^MO\#``),#0```#H:?[_S"R3P`0ZQ$`(``-P"```#:WLD\`
M$>,@(```!$$P\,3C,/"X`"3C("```!:Y!`"CT@?PR!`HP.7__^`2P&```#:?
MN00`LN,08```!.,@$```%L#E___@!+D$`#K2`+"Q(+#`(````\W`Y?__\,FY
M`@`BIX0`!I4Q(`"GA`&=P.7___?FXQ!@```$XR`0```6P.7__]_EIUD`"Z=)
M``'`,```!*?`Y?__W@NY`@`BIX0`C>,0(!``!,!P```^]>,0$"@`!.,0\*``
M)%@0<`"G'@`!I\0`>^,08```!.,0\*@`),`0```^W*>H``"GN``!XQ#PL``D
MI_0`%N,@(!``!*<(``"R70`IIQ3__J=T`%:GJ@`!I[H``5@0<``9&Z?$`$_C
M$/"H``3C(!```!;`Y?__WY:G60``N10`2N,P\*``!,#E___?++D"`(*GA``V
MXR#PL``$N10`&^L1``,`#>-`(```!.,@@```!%@PT`14,"`,ISX$`..10```
M!*>$_[[C$&````3C(!```!;`Y?__WV;C,(````2G60`"ITD``,#E___<_*<(
M``"R70`IIQ3__J>$_ZY8$'``&"&G*O__&2JGA`#;X[!@```$XR"P```6P.7_
M_]]#IUD``Z=)``'`,```!`C`Y?__W6FY`@"BIX0`'N,@L```%L#E___?+^,0
MH!``!,!````#]N,P$```!,#E___<L^,0H!``!.,0$```!)%`$`VG=`#ZX[!@
M```$XR"P```6P.7__]\0IUD``Z=)``'`,````]G`Y?__W3:Y`@"BIX0`(.,P
M\+@`!,`@```"LL#E___OR;D"`)+C(+```!:GA`"\P.7__][OXQ"@$``$N00`
M2>,P$```!,#E___<=.,08```!,"@```^!N,@$```%L#E___>V,`0```U9;D$
M`++C$!````3C(!```!;`Y?__WLJG20`!P#````.6P.7__]UBP$````.;N00`
M,KD$`"O`Y?__W$C`$```-47C$!````3C(!```!;`Y?__WJSC,/"X``22`""Q
MP"````)5P.7__^]QXR"@```DN0(`(KD$`+*GA`!*ISD!P+D$`"O`Y?__W8&G
M+@`1IX0`"1@2IQH``540T`"G)`![LD\`$.L1`"``#;)/`!'5!_#($"BG=`!L
MXT#Q0``$ZV_Q```$!_2G'@`!I\3_):>X``'CH&````3C(*```!;`Y?__WF3C
M,/"@``3`Y?__VVZGN@`!6;!P`*=$__"G]/\,E0`@`:>$_F:G]/YAP!```#UM
MXR`0```$P.7___A'XR"@```DN0(`(KD$`+*G=/^HP"````,:P.7__]T(P.7_
M_]XUP!```#U2XR"@$``$XQ`0```$XR`@```$XS`0```$P.7___)[I_3_/^,@
ML```%L#E___>&^,0H!``!.,P$```!,#E___=0J?T_OG`Y?__VUW`$```/2JY
M!`!2XQ`0```$N00`2\`@```"\.,P$```!,#E___<R@<'!P<'!^NO\%``),#0
M```!9:?[_V"Y!`"BP.7___4FXQ`@``"0N0(`$:>$`$080;D$`+)!$"`!I_0`
M#.,P$```D*<;``&Y`@`S&$.GA``2O4'0`*=T__3C,!```)"Y!`"QIQL``;D"
M`#,80Z=T__+`Y?__]I<2(J>$`!:Y`@"JIX0`$I4`H`"GA``.P#````(`N00`
M*\#E___:7+D@`+*GA``-XT#Q$``$ZZ_P\``$!_2Y!`"RI_3_W;D$`"KKK_#P
M``3`]/__\,$'!P<'P!```#0LXQ`0```$N0(`$:>$``CC4!````3`]/__VU.G
M60``P/3__]M.!P<'!P<'ZW_P.``DI_O_8+D$`**Y!`"3N00`A,#E___9[<"P
M```QSL`0```QQ[D)`+'KNP`#``JGA``2N00`<>,0<```!+D$`$BY!``YN00`
M*J=[``@-X:>W__3C0/$0``3K?_#8``0']`<'!P<'_@<'!P<'!^MO\#``)+D$
M`!^G^_]@XQ#P```DP,```#+"!P?C0/$0``3K;_#0``0']`<'```````"``$`
M``````````````X``````````````````````````,IBP=8`````CQN\W```
M``!NV>NA`````%J">9D`````_____P``````````````_P```#T``*``````
M````@```````+P`````````````````0`%]?14Y67U!!4E]#3$5!3E]?("`@
M("`@("`@("`@("`@````````````````````,``````````#________?\\`
M`````____P````#_____`````,/2X?``````$#)4=@````"8NMS^`````._-
MJXD`````9T4C`0``````````````````@A@```````"!\/_______W``````
M````@>C_______]]Z````#\````1````_P`````````!`"`$`"\`````````
M'_________]P97)L>'-I+F,`````````)7,O)7,`+W!R;V,O<V5L9B]E>&4`
M`$1Y;F%,;V%D97(Z.F)O;W1?1'EN84QO861E<@!);G1E<FYA;',Z.E!!4CHZ
M0D]/5```+W!R;V,O)6DO)7,`97AE`"X`4$%27U1%35```%!!4E]04D]'3D%-
M10``.@`O`%!%4DPU3$E"``!015),3$E"`%!%4DPU3U!4``!015),24\``%!!
M4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X`4$%27T1%0E5'
M`%!!4E]#04-(10!005)?05)'0P``4$%27T%21U9?,```4$%27T=,3T)!3%]$
M14)51P``4$%27T=,3T)!3%]435!$25(`4$%27U1-4$1)4@``4$%27T=,3T)!
M3%]414U0`%!!4E]'3$]"04Q?0TQ%04X``%!!4E]#3$5!3CT``#$`3$E"4$%4
M2`!,24)205)97U!!5$@``$193$1?3$E"4D%265]0051(`%-(3$E"7U!!5$@`
M`%-94U1%30``)3`R>```)7,E<R5S)7,``'!A<BT``"5S.B!C<F5A=&EO;B!O
M9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL960@*&5R<FYO/25I*0H`
M`'!A<FP``"YP87(``"5S)7-C86-H92TE<R5S```E<R5S=&5M<"TE=25S`"5S
M)7-T96UP+25U+25U)7,``"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I
M<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E
M<F%T:6]N*0H``"]T;7```%1%35!$25(`5$U0`%5315(``%5315).04U%``!!
M4D=6```8`'!E<FP``#``4$%2.CI086-K97(Z.E9%4E-)3TX``#$N,#,V`%5N
M86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y```E<SH@8W)E871I;VX@
M;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N
M;STE:2D*```M90``+2T``&5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@+5,@
M)#`@)'LQ*R(D0")])PII9B`P.R`C(&YO="!R=6YN:6YG('5N9&5R('-O;64@
M<VAE;&P*<&%C:V%G92!?7W!A<E]P;#L*;7D@*"1P87)?=&5M<"P@)'!R;V=N
M86UE+"!`=&UP9FEL92D["D5.1"![(&EF("@D14Y6>U!!4E]#3$5!3GTI('L*
M<F5Q=6ER92!&:6QE.CI496UP.PIR97%U:7)E($9I;&4Z.D)A<V5N86UE.PIR
M97%U:7)E($9I;&4Z.E-P96,["FUY("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M
M93HZ9&ER;F%M92@D<&%R7W1E;7`I.PIO=71S*'%Q>U)E;6]V:6YG(&9I;&5S
M(&EN("(D<&%R7W1E;7`B?2D["D9I;&4Z.D9I;F0Z.F9I;F1D97!T:"AS=6(@
M>R`H("UD("D@/R!R;61I<B`Z('5N;&EN:R!]+"`D<&%R7W1E;7`I.PIR;61I
M<B`D<&%R7W1E;7`["FEF("@M9"`D<&%R7W1E;7`@)B8@)%Y/(&YE("=-4U=I
M;C,R)RD@>PIM>2`D=&UP(#T@;F5W($9I;&4Z.E1E;7`H"E1%35!,051%(#T^
M("=T;7!86%A86"<L"D1)4B`]/B!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D
M=&]P9&ER*2P*4U5&1DE8(#T^("<N8VUD)RP*54Y,24Y+(#T^(#`L"BD["G!R
M:6YT("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=
M.R!D;PIR;2`M<F8@)R1P87)?=&5M<"<*:68@6R!<(2`M9"`G)'!A<E]T96UP
M)R!=.R!T:&5N"F)R96%K"F9I"G-L965P(#$*>#U@97AP<B!<)'@@*R`Q8`ID
M;VYE"G)M("<B("X@)'1M<"T^9FEL96YA;64@+B`B)PHB.PIC:&UO9"`P-S`P
M+"1T;7`M/F9I;&5N86UE.PIM>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G
M(#XO9&5V+VYU;&P@,CXF,2`F)SL*8VQO<V4@)'1M<#L*<WES=&5M*"1C;60I
M.PIO=71S*'%Q*%-P87=N960@8F%C:V=R;W5N9"!P<F]C97-S('1O('!E<F9O
M<FT@8VQE86YU<#H@*0HN("1T;7`M/F9I;&5N86UE*3L*?0I]('T*0D5'24X@
M>PI);G1E<FYA;',Z.E!!4CHZ0D]/5"@I(&EF(&1E9FEN960@)DEN=&5R;F%L
M<SHZ4$%2.CI"3T]4.PIE=F%L('L*7W!A<E]I;FET7V5N=B@I.PII9B`H97AI
M<W1S("1%3E9[4$%27T%21U9?,'T@86YD("1%3E9[4$%27T%21U9?,'T@*2![
M"D!!4D=6(#T@;6%P("1%3E9[(E!!4E]!4D=67R1?(GTL("@Q("XN("1%3E9[
M4$%27T%21T-]("T@,2D["B0P(#T@)$5.5GM005)?05)'5E\P?3L*?0IE;'-E
M('L*9F]R("AK97ES("5%3E8I('L*9&5L971E("1%3E9[)%]](&EF("]>4$%2
M7T%21U9?+SL*?0I]"FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY
M("5#;VYF:6<@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@
M/R`G.R<@.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7
M:6Y\3U,R?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]
M/B`H)%Y/(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T
M7W!R;V=N86UE*"D["E]S971?<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L
M("1D871A7W!O<RD["GL*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT[
M"F]P96X@7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PIB:6YM;V1E*%]&
M2"D["FUY("1B=68["FUY("1S:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D;V9F
M<V5T(#T@-3$R.PIM>2`D:61X(#T@+3$["G=H:6QE("@Q*0I["B1O9F9S970@
M/2`D<VEZ92!I9B`D;V9F<V5T(#X@)'-I>F4["G-E96L@7T9(+"`M)&]F9G-E
M="P@,B!O<B!D:64@<7%;<V5E:R!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A
M73L*;7D@)&YR96%D(#T@<F5A9"!?1D@L("1B=68L("1O9F9S970["F1I92!Q
M<5MR96%D(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=('5N;&5S<R`D;G)E
M860@/3T@)&]F9G-E=#L*)&ED>"`](')I;F1E>"@D8G5F+"`B7&Y005(N<&U<
M;B(I.PIL87-T(&EF("1I9'@@/CT@,"!\?"`D;V9F<V5T(#T]("1S:7IE('Q\
M("1O9F9S970@/B`Q,C@@*B`Q,#(T.PHD;V9F<V5T("H](#(["GT*;&%S="!U
M;FQE<W,@)&ED>"`^/2`P.PHD;V9F<V5T("T]("1I9'@@+2`T.PIS965K(%]&
M2"P@+21O9F9S970L(#(["G)E860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@
M+21O9F9S970@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*<F5A9"!?1D@L("1B
M=68L(#0["B1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PIM>2`E<F5Q=6ER
M95]L:7-T.PIW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B
M=68L(#0["G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@
M)&9U;&QN86UE(#T@)&)U9CL*;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U
M;&QN86UE(BXN+BDI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA
M+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D
M97AT*2`]("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@
M7T9(+"`D8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U
M9BD["FEF("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L
M?&EX?&%L*20O:2D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1C<F,D
M97AT(BP@)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U
M;&QN86UE?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD
M9FEL96YA;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^
M(&U\7B\_<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*
M;7D@)&9I;&5N86UE(#T@7W1E;7!F:6QE*"(D8F%S96YA;64D97AT(BP@)&)U
M9BP@,#<U-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L<V4@
M>PHD<F5Q=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2.CI(96%V>3HZ36]D
M=6QE0V%C:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D
M8W)C+`IN86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@
M-#L*?0IL;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@
M/2!`7SL*<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D
M9FEL96YA;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D
M;R!["FUY("1K97D["F9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PIN
M97AT('5N;&5S<R`O7%$D;6]D=6QE7$4D+SL*)&ME>2`]("1?.R!L87-T.PI]
M"F1E;&5T92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D[
M"GT@;W(@<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N
M86UE+R1M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D
M*"9)3SHZ1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M
M<&9I;&4@;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D9FEL
M96YA;64M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E='5R;B`D9F@["GT*
M96QS92!["FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&9I;&5N86UE+3Y[
M8W)C?2YP;2(L("1F:6QE;F%M92T^>V)U9GTI.PIO<&5N(&UY("1F:"P@)SPG
M+"`D9FEL96YA;64@;W(@9&EE(")C86XG="!R96%D("1F:6QE;F%M93H@)"$B
M.PIB:6YM;V1E*"1F:"D["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P
M:6YG(&9A:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I
M.PIR97%U:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I
M<F4@0V%R<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z
M.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4[
M"G=H:6QE("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI
M<W0I6S!=*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M
M92`]?B`O0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI
M('L*<F5Q=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U
M;FQE<W,@)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*
M9&5L971E("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S
M<R`D8G5F(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&
M2"D@+2`T.PI]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L
M;V=F:"P@)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%
M?3L@(R!S86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE
M;2D*)'%U:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S
M=&%R=%]P;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S
M:&EF="DI('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II
M("`@:6YS=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R
M"G8@("!V97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@
M)RTM<F5U<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5]
M(#T@<VAI9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I
M;W5R"FUY($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@
M/7X@+UXM*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q
M(&5Q("=))RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@
M97$@)TTG*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@
M>PIU;G-H:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@
M>PHD;W5T(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@
M)W-I=&4G.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG
M.PI]"F5L<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H
M)#$@97$@)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA8
M6#H@0V%N;F]T(&]P96X@;&]G.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4)RD@
M>PHD8V%C:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C
M;60@/2`D9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=]
M.PII;FET7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T
M.CHD8VUD(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]
M*"1?*2!F;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?
M=&]?:6YC.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR
M97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I
M.PIM>2`D>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["D%R8VAI=F4Z.EII<#HZ
M<V5T0VAU;FM3:7IE*#$R."HQ,#(T*3L*;W!E;B!M>2`D9F@L("<\)RP@)'!A
M<B!O<B!D:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PIB:6YM;V1E*"1F
M:"D["F)L97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI:
M:7`M/FYE=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R
M*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@(E)E860@)R1P
M87(G(&5R<F]R.B`D(2(["GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD
M(&UY("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE
M=&$@/7X@<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD
M;65T82`]?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*;&]C86P@)"\@
M/2!<-#L*:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(%!!4BP@)SPG+"`D<&%R
M(&]R(&1I92`B)"$Z("1P87(B.PIB:6YM;V1E*%!!4BD["F1I92`B)'!A<B!I
M<R!N;W0@82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T
M(CL*?0I#<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE
M=R@*)&]U="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=2
M3TY,62@I('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@
M)"$["F)I;FUO9&4H)&9H*3L*)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@
M7"1D871A7W!O<R`Z('5N9&5F.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E
M<B`]('-C86QA<B`\7T9(/CL*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD
M("1L;V%D97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&
M:6QT97(Z.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^
M87!P;'DH7"1L;V%D97(L("0P*0I]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K
M97ES("5E;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A
M;"`](&5V86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`]
M(")?7T5.5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")0
M05)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I
M8R@@*RE]>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@
M;&5N9W1H*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD["B0O
M(#T@=6YD968["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*
M4$%2.CI(96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR
M97%U:7)E7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@
M?0IG<F5P('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I
M9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF
M:6=[<')I=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*)&9I;&5S>R1?
M?2LK(&9O<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E
M<R`E24Y#.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT
M?3L*;7D@)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*
M;7D@*"1N86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII
M9B`H)&YA;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL
M92`]("1?.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI
M*5Q:+VDI('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE
M;'-I9B`H;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*:68@*&UY
M("1R968@/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL
M92P@)&YA;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D
M:7(O)#$B*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL
M87-T.PI]"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@
M)'=R:71T96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F
M:6QE(#U^("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN("(B+`IQ<2A0
M86-K:6YG("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L
M"G%Q*"(N+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD
M8V]N=&5N="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G
M/"<L("1F:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM
M;V1E*$9)3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2
M.CI&:6QT97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I
M;&4I"FEF("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_
M.G!M?&EX?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W
M+3YA<'!L>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*;W5T<RAQ<2A7
M<FET=&5N(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B1DE,12(I.PHD9F@M
M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PHD9F@M/G!R
M:6YT*'-P<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E
M0U)#,S(H)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP<FEN="AP86-K*"=.
M)RP@;&5N9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT*"1C;VYT96YT*3L*
M?0I]"B1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A
M8VAE7VYA;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H(21C
M86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*
M;7D@)&-T>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z
M.E-(02T^;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q
M.R!$:6=E<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S
M=#HZ340U.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`]
M(&5V86P@>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H
M85]V97)S:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG
M*2!["B1C='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["GT*96QS
M92!["FEF("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*8FEN
M;6]D92@D9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*
M?0HD8V%C:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I
M;64["GT*)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C
M:&5?;F%M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H
M)&-A8VAE7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@
M+2!L96YG=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I
M.PHD9F@M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S
M="!U;FQE<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D[
M"G)E<75I<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D[
M"GL*<F5Q=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*
M?0IM>2`D>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["FUY("1F:"`]($E/.CI&
M:6QE+3YN97<["B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I
M92`B)"$Z("1`(CL*)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R
M;V=N86UE*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@
M)$`B.PIP=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H
M97LD<')O9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'
M?3L*;W5T<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB
M*2D["FEF("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E
M('-E="!A="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP
M+3YM96UB97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM
M>2`D;65M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE
M<W,@)&UE;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ
M0V]N9FEG>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M
M97TO*3\**%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY
M("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%
M35!]+"`D97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@
M7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<2A3
M:VEP<&EN9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T
M<R!A="`B)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ<2A%>'1R86-T
M:6YG("(D;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PHD;65M8F5R
M+3YE>'1R86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D*#`U-34L
M("1D97-T7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S
M("@D4$%2.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL
M97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@
M6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@
M+4)\+6(@72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!
M345](#T@)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R
M96%T95!A=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S
M96YA;64["FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A
M<V5N86UE.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&
M:6QE.CI0871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M
M92`D<&%T:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U
M:7)E7VUO9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R
M.PIR97%U:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A
M<FYI;F=S.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#
M87)P.CI(96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ
M2&5A=GD["G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I
M<F4@1FEL93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A3
M3&]A9&5R.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR
M97%U:7)E($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U
M:7)E($%R8VAI=F4Z.EII<#L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(
M96%V>3L*<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0[
M"G)E<75I<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V
M86P@>R!R97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ
M571I;"!].PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@
M?3L*979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*
M979A;"![(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R
M('T["F5V86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M
M<"!["FEF("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]4
M14U0?2`]?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF
M;W)E86-H(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$
M25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O
M=&UP("X@*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@
M)'!A=&@@86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*
M979A;"![*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM]
M.PII9B`H(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA
M;64@/2`F5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U
M:60I('L*)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@
M/2`D14Y6>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]
M"B1U<V5R;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D
M0V]N9FEG>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*
M;6MD:7(@)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N
M9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM
M>2`D9F@L("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES
M<F5A9"`D9F@L(&UY("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@
M>PIS965K("1F:"P@+34X+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B
M=68@/7X@<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A
M8VAE+2(@+B`D8G5F.PI]"F5L<V4@>PIM>2`D8W1X(#T@979A;"![(')E<75I
M<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L
M('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*
M?'P@979A;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN
M97<@?3L*;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ
M5D524TE/3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R
M("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D<')O
M9VYA;64L(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@
M;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE(BDI('L*8FEN;6]D92@D9F@I.PHD
M8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD<W1M<&1I<B`N
M/2`B)$-O;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE
M>&1I9V5S="`Z("1M=&EM92`I.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%
M3E9[4$%27T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI
M;7UT96UP+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I
M<B`D<W1M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D
M14Y6>U!!4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]
M"G-U8B!?=&5M<&9I;&4@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I
M(#T@0%\["FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE
M<W,@*"UE("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE
M+B0D(CL*;W!E;B!M>2`D9F@L("<^)RP@)'1E;7!N86UE(&]R(&1I92`B8V%N
M)W0@=W)I=&4@)'1E;7!N86UE.B`D(2(["F)I;FUO9&4@)&9H.PIP<FEN="`D
M9F@@)&-O;G1E;G1S.PIC;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA
M;64@:68@9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN
M86UE*2!O<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE
M.PI]"G-U8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?
M4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2![
M"B1P<F]G;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6
M>U!!4E]414U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0
M?2D@/CT@,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD
M97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D
M14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG
M>U]D96QI;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G
M;F%M92D@>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE
M)$-O;F9I9WM?97AE?2(I('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T[
M"G)E='5R;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I
M9WMP871H7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@
M)$5.5GM005)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D
M:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]
M("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I
M+"!L87-T*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#
M;VYF:6=[7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L
M:6U])'!R;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D
M<')O9VYA;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P
M<F]G;F%M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@
M(BXD0V]N9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F
M:6YE9"`F0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE
M9"`F5VEN,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D[
M"F-H;VUP*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF
M:6=[7V1E;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?
M4%)/1TY!345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*
M:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX[
M"GT@96QS92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ
M=R@@4U!!5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%($%2
M1T,@05)'5E\P("D@*2!["F1E;&5T92`D14Y6>R=005)?)RXD7WT["GT*9F]R
M("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R=005)?
M)RXD7WT@/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6
M>R=005)?1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?8VQE86X@/2`B7U]%3E9?
M4$%27T-,14%.7U\@("`@("`@("`@("`@("`B.PII9B`H)$5.5GM005)?5$5-
M4'TI('L*9&5L971E("1%3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H(65X:7-T
M<R`D14Y6>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU92`]('-U8G-T
M<B@D<&%R7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%3E9[4$%2
M7T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\[
M"GT*?0IS=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I
M('L*<')I;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB
M.PI]"GT*<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.
M0RP@9W)E<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H
M"F%R8VAL:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP
M"G9E;F1O<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN
M.PIR97%U:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87([
M"E!!4BT^:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<2AP87(N<&PZ($-A;B=T
M(&]P96X@<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O
M<B!D:7)E8W1O<GE<;BD*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N
M86UE.PI#3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD
M*RE<*2\I.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D
M0#L*?0I#3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58
M251?7"@H7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U([
M"C$["E]?14Y$7U\*`````1L#.P```-0````9__]Y>```!8C__WW`````\/__
MFG@```$P__^;<````8#__YPX```!L/__GS````'P__^@R````C#__Z&(```"
M</__HJ````*H__^BZ````LC__Z-@```#"/__I)````-(__^DF````V#__Z;X
M```#H/__IU````.X__^HR```!`#__ZJ(```$,/__JS@```1@__^K>```!(C_
M_ZS8```$R/__N'````4(__^\\```!4C__[VX```%R/__O>@```7@__^^4```
M!A@`````````%``````!>E(``7@.`1L,#Z`!````````/````!S__WS(```<
MM@!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5*#M`'`QR>"L_.S<S+RLG(Q\8.H`%"
M"P```````$P```!<__^90````/0`1H8.APV(#(D+B@J+"8P(C0>.!H\%1`[`
M`@*T"L_.S<S+RLG(Q\8.H`%""V(*QL?(R<K+S,W.SPZ@`4(+````````+```
M`*S__YGH````R`!4B@J+"8P(C0>.!H\%1`[0`@*H"L_.S<S+R@Z@`4(+````
M/````-S__YJ````"\@!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5*#N@"`P&,"L_.
MS<S+RLG(Q\8.H`%""P```````#P```$<__^=.````90`5(8.APV(#(D+B@J+
M"8P(C0>.!H\%1`[@`WH*S\[-S,O*R<C'Q@Z@`4(+```````````\```!7/__
MGI````#``$:*"HL)C`B-!XX&CP5*#L`"`DP*S\[-S,O*#J`!0@L"8,K+S,W.
MSPZ@`0``````````-````9S__Y\0```!%`!*B`R)"XH*BPF,"(T'C@:/!40.
MR"("P@H.H`%,S\[-S,O*R<A""P`````<```!U/__G_````!&`%*.!H\%1`[`
M`FK/S@Z@`0```#P```'T__^@&````'0`4H8.APV(#(D+B@J+"8P(C0>.!H\%
M1`[(`@)<S\[-S,O*R<C'Q@Z@`0`````````````\```"-/__H%````$N`$J&
M#H<-B`R)"XH*BPF,"(T'C@:/!40.V$("P`H.H`%,S\[-S,O*R<C'QD(+````
M````%````G3__Z%`````!@``````````````/````HS__Z$P```"7@!&A@Z'
M#8@,B0N*"HL)C`B-!XX&CP5*#N`B`H8*#J`!3,_.S<S+RLG(Q\9""P``````
M`!0```+,__^C4````%(``````````````$0```+D__^CD````7@`1HT'C@:/
M!4H.P`("8@K/SLT.H`%&"V8*S\[-#J`!0@L"G`K-SL\.H`%""V@*S<[/#J`!
M0@L``````"P```,L__^DP````;X`5(L)C`B-!XX&CP5$#O`"`P%4"L_.S<S+
M#J`!0@L``````"P```-<__^F4````+``1HL)C`B-!XX&CP5*#M`"`DX*S\[-
MS,L.H`%""P```````"0```.,__^FT````#H`1HX&CP5$#L`"9@K/S@Z@`4(+
M```````````\```#M/__IN@```%<`%2&#H<-B`R)"XH*BPF,"(T'C@:/!40.
MH`,"S`K/SLW,R\K)R,?&#J`!0@L`````````/````_3__Z@(```+E@!&A@Z'
M#8@,B0N*"HL)C`B-!XX&CP5,#KB%`@,"\@H.H`%,S\[-S,O*R<C'QD(+````
M`#P```0T__^S8```!'H`1H8.APV(#(D+B@J+"8P(C0>.!H\%2@[P`@,#=@K/
MSLW,R\K)R,?&#J`!0@L````````\```$=/__MZ````#$`$:*"HL)C`B-!XX&
MCP5*#L`"`IH*S\[-S,O*#J`!0@M2S\[-S,O*#J`!````````````/```!+3_
M_W/H```"X`!&A@Z'#8@,B0N*"HL)C`B-!XX&CP5*#N@"`P(4"L_.S<S+RLG(
MQ\8.H`%""P```````!0```3T__^WZ````"H``````````````#0```4,__^X
M`````&0`1H<-B`R)"XH*BPF,"(T'C@:/!40.P`("6,_.S<S+RLG(QPZ@`0``
M````%```!43__[@P`````@``````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M`````````````````````````````````"<H````````)M``````````````
M```````!``````````$``````````0````````'?``````````$````````!
MZ@`````````!`````````?0``````````0````````)#``````````$`````
M```#?``````````,````````&X@`````````#0```````&@(`````````!D`
M``````#+2``````````;``````````@`````````&@```````,M0````````
M`!P`````````"`````!O__[U`````````I``````````!0````````S0````
M``````8````````#<``````````*````````!.``````````"P`````````8
M`````````!4````````````````````#````````S:```````````@``````
M``5P`````````!0`````````!P`````````7````````%A@`````````!P``
M`````!+H``````````@````````#,``````````)`````````!@`````````
M'@`````````(`````&____L`````"````0````!O___^````````$G@`````
M;____P`````````"`````&____`````````1L`````!O___Y`````````!4`
M````````````````````````````````````````````````````````````
M`````````````````````````````````````````````````````,M@````
M`````````````````````````!OV````````'!8````````<-@```````!Q6
M````````''8````````<E@```````!RV````````'-8````````<]@``````
M`!T6````````'38````````=5@```````!UV````````'98````````=M@``
M`````!W6````````'?8````````>%@```````!XV````````'E8````````>
M=@```````!Z6````````'K8````````>U@```````![V````````'Q8`````
M```?-@```````!]6````````'W8````````?E@```````!^V````````']8`
M```````?]@```````"`6````````(#8````````@5@```````"!V````````
M()8````````@M@```````"#6````````(/8````````A%@```````"$V````
M````(58````````A=@```````"&6````````(;8````````AU@```````"'V
M````````(A8````````B-@```````")6````````(G8````````BE@``````
M`"*V````````(M8````````B]@```````",6````````````````````````
M``````````````````````````````````````````````````````````#0
M"``````````````````````````````C*```````````````````````````
M``````````````````````````````````#0"````````&KR````````:MH`
M``````!JX@```````&L(````````:O````````!K`@``````````````````
M:_@```````!IZ```````````````````:IX```````!JH@```````&O^````
M````:>X```````!L!@``````````````````;`H```````!L$```````````
M_____P````````````!LLD=#0SH@*$1E8FEA;B`V+C,N,"TR*2`V+C,N,"`R
M,#$V,3(R.0!'0T,Z("A$96)I86X@-BXR+C$M-2D@-BXR+C$@,C`Q-C$Q,C0`
M`"YS:'-T<G1A8@`N:6YT97)P`"YN;W1E+D%"22UT86<`+FYO=&4N9VYU+F)U
M:6QD+6ED`"YG;G4N:&%S:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N
M`"YG;G4N=F5R<VEO;E]R`"YR96QA+F1Y;@`N<F5L82YP;'0`+FEN:70`+G1E
M>'0`+F9I;FD`+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N:6YI
M=%]A<G)A>0`N9FEN:5]A<G)A>0`N:F-R`"YD>6YA;6EC`"YG;W0`+F1A=&$`
M+F)S<P`N8V]M;65N=```````````````````````````````````````````
M``````````````````````````````````````````````````````````L`
M```!``````````(````````".`````````(X``````````\`````````````
M```````!```````````````3````!P`````````"`````````D@````````"
M2``````````@````````````````````!```````````````(0````<`````
M`````@````````)H`````````F@`````````)`````````````````````0`
M`````````````#1O___V``````````(````````"D`````````*0````````
M`-P````%```````````````(```````````````^````"P`````````"````
M`````W`````````#<`````````E@````!@````(`````````"``````````8
M````1@````,``````````@````````S0````````#-`````````$X```````
M``````````````$``````````````$YO____``````````(````````1L```
M`````!&P`````````,@````%```````````````"``````````(```!;;___
M_@`````````"````````$G@````````2>`````````!P````!@````(`````
M````"```````````````:@````0``````````@```````!+H````````$N@`
M```````#,`````4```````````````@`````````&````'0````$````````
M`$(````````6&````````!88````````!7`````%````%@`````````(````
M`````!@```!^`````0`````````&````````&X@````````;B`````````!`
M````````````````````!```````````````>0````$`````````!@``````
M`!O(````````&\@````````'8`````````````````````0`````````(```
M`(0````!``````````8````````C*````````",H````````1.``````````
M```````````(``````````````"*`````0`````````&````````:`@`````
M``!H"``````````L````````````````````!```````````````D`````$`
M`````````@```````&@X````````:#@```````!!=@``````````````````
M``@``````````````)@````!``````````(```````"IL````````*FP````
M`````-0````````````````````$``````````````"F`````0`````````"
M````````JH@```````"JB`````````5<````````````````````"```````
M````````L`````X``````````P```````,M(````````NT@`````````"```
M``````````````````@`````````"````+P````/``````````,```````#+
M4````````+M0``````````@````````````````````(``````````@```#(
M`````0`````````#````````RU@```````"[6``````````(````````````
M````````"```````````````S0````8``````````P```````,M@````````
MNV`````````"0`````8```````````````@`````````$````-8````!````
M``````,```````#-H````````+V@`````````F`````````````````````(
M``````````@```#;`````0`````````#````````T`````````#`````````
M``"X````````````````````"```````````````X0````@``````````P``
M`````-"X````````P+@````````0,`````````````````````@`````````
M`````.8````!`````````#```````````````````,"X`````````$H`````
M```````````````!``````````$````!`````P``````````````````````
G``````#!`@````````#O`````````````````````0``````````
